<?php
/**
 * The Horde_Text_Rst_Formatter_html:: class is the HTML formatter.
 *
 * $Horde: framework/Text_Rst/lib/Horde/Text/Rst/Formatter/Html.php,v 1.2.2.2 2008/01/02 11:30:57 jan Exp $
 *
 * Copyright 2003-2008 The Horde Project (http://www.horde.org/)
 *
 * See the enclosed file COPYING for license information (LGPL). If you
 * did not receive this file, see http://opensource.org/licenses/lgpl-license.php.
 *
 * @author  Jason M. Felice <jason.m.felice@gmail.com>
 * @author  Chuck Hagenbuch <chuck@horde.org>
 * @category Horde
 * @package Horde_Text_Rst
 */
class Horde_Text_Rst_Formatter_Html extends Horde_Text_Rst_Formatter
{
    /**
     */
    public function format($node, $charset = null)
    {
        if (!isset($charset)) {
            $charset = $this->_charset;
        }

        if (is_string($node)) {
            if (isset($charset)) {
                return @htmlspecialchars($node, ENT_QUOTES, $charset);
            } else {
                return htmlspecialchars($node, ENT_QUOTES);
            }
        }

        switch ($node->getType()) {
        case 'document':
            return $this->_children($node);

        case 'heading':
            $level = $node->level;
            return '<h' . $level . '>' . $this->_children($node) . '</h' .
                $level . '>';

        case 'link':
            return '<a href="' .
                (isset($charset) ?
                 @htmlspecialchars($node->href, ENT_QUOTES, $charset) :
                 htmlspecialchars($node->href, ENT_QUOTES)) .
                '">' .
                $this->_children($node) . '</a>';

        case 'literal-block':
            list($text) = $node->children;
            return '<pre class="literal-block">' . "\n" . (isset($charset) ?
                              @htmlspecialchars($text, ENT_QUOTES, $charset) :
                              htmlspecialchars($text, ENT_QUOTES)) . "\n</pre>\n";

        case 'bullet_list':
            return '<ul class="simple">' . "\n"
                . $this->_children($node) . "</ul>\n";

        case 'list_item':
            $item = '<li>';
            if (count($node->children) == 1) {
                $item .= $this->_children($node->children[0]);
            } else {
                $item .= $this->_children($node);
            }
            $item .= "</li>\n";
            return $item;

        case 'paragraph':
            return '<p>' . $this->_children($node) . "</p>\n";

        case 'interpreted-text':
            switch ($node->role) {
            case 'emphasis':
                return '<em>' . $this->_children($node) . '</em>';

            case 'literal':
                return '<tt>' . $this->_children($node) . '</tt>';

            case 'strong':
                return '<strong>' . $this->_children($node) . '</strong>';

            case 'superscript':
                return '<sup>' . $this->_children($node) . '</sup>';

            case 'subscript':
                return '<sub>' . $this->_children($node) . '</sub>';

            case 'title-reference':
                return '<cite>' . $this->_children($node) . '</cite>';

            default:
                // XXX: Issue a warning.
                return $this->_children($node);
            }

        case 'section':
            return $this->_children($node);
        }
    }

    /**
     */
    protected function _children($node)
    {
        $result = '';
        foreach ($node->children as $child) {
            $result .= $this->format($child);
        }
        return $result;
    }

}
